#!/usr/bin/env python
# -*- coding: utf-8 -*-

import pandas as pd

ACTION = 'action'
AREA_COLUMN = 'Area'
CHEMICAL_FORMULA_COLUMN = 'ChemicalFormula'
CHEMICAL_FORMULA_FILE = 'data_files/hmdb_2016_06_11_formula_mass_UPDATED.csv'
CIT = 'cit'
COMP_DATA = "data_files/mimosa_compound_database_withRT.csv"
COMP_HMDB_FILE = "data_files/compound_hmdb_list.csv"

COMP_ISO_COL = ['Metab', 'Name', 'Phenotype', 'Isotopologue', 'Time Course', 'Sample_no',
                'Fractional Enrichment']
COMP_ISO_COL1 = ['Phenotype', 'Isotopologue', 'Name', 'Time Course', 'Sample_no']
COMP_AREA = ['Metab','Phenotype', 'Name', 'Time Course', 'Intensity', 'NA Corrected']
COMPONENT_NAME_COLUMN = 'Component Name'
COMPOUND_COLUMN = 'compound'
COMPOUNDID_COLUMN = "compoundId"
CONVERSION_DICT = {"na_lcms": 'convert_file_LCMS',
                   "na_msms": 'convert_file_MSMS',
                   "quant_lcms": 'convert_lcms_quant',
                   "quant_msms": 'convert_msms_quant',
                   "maven_qc": 'convert_maven_to_sample_qc',
                   "maven_pvd": 'convert_maven_to_unlabelled_pvd',
                   "na_msms_rna": 'convert_RNA_file_MSMS',
                   'isocorrect_quant_lcms':'convert_isocorrect_to_quant_lcms',
                   'isocorrect_qc_lcms':'convert_isocorrect_to_quickcheck_lcms',
                   'quant_qc_lcms':'convert_quantfit_to_quickcheck_lcms',
                   'quant_metscape_lcms':'convert_quantfit_to_metscape_lcms'
                   }
DATE_TIME = "%Y-%m-%d_%H-%M-%S"
ERRORS = 'errors'
ERR_FILE_DOESNOT_EXIST_MSG = 'The file does not exist'
ERR_DF_EMPTY_MSG = 'The dataframe is empty'
ERR_FILE_EXTN_MSG = 'only csv/xls/xlsx/txt extensions are allowed'
ERR_EMPTY_FILE_MSG = 'The file is empty'
ERR_MISSING_COL_MSG = 'The required columns are missing'

EXTRA_COLUMNS_LIST = ['maxQuality', 'expectedRtDiff',
                      'ppmDiff', 'parent', 'goodPeakCount']

EXTRA_COLUMNS_LIST_QUANT = ['label', 'metaGroupId', 'groupId', 'groupId',
                      'maxQuality', 'compoundId', 'expectedRtDiff',
                      'ppmDiff', 'medRt', 'parent', 'goodPeakCount',
                      'medMz', 'note', 'isotopeLabel', 'adductName']

EXTRA_COLUMNS_LIST_SAMPLE_QC = ['label', 'metaGroupId', 'groupId',
                        'goodPeakCount', 'expectedRtDiff', 'medMz', 'medRt',
                        'maxQuality', 'compoundId', 'formula', 'ppmDiff',
                        'parent', 'adductName']

EXTRA_COLUMNS_LIST_SAMPLE_QC_OLD = ['label', 'metaGroupId', 'groupId',
                        'goodPeakCount', 'expectedRtDiff', 'medMz', 'medRt',
                        'maxQuality', 'compoundId', 'ppmDiff',
                        'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD_OLD = ['label', 'metaGroupId', 'groupId', 'goodPeakCount', 'maxQuality',
         'medMz', 'medRt', 'note', 'compound', 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD_OLD_KEEP_DUPLICATE_NAMES = ['label', 'metaGroupId', 'groupId', 'goodPeakCount', 'maxQuality',
         'medMz', 'note', 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD = ['label', 'metaGroupId', 'groupId', 'goodPeakCount', 'maxQuality',
         'medMz', 'medRt', 'note', 'compound', 'formula', 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD_KEEP_DUPLICATE_NAMES = ['label', 'metaGroupId', 'groupId', 'goodPeakCount', 'maxQuality',
         'medMz', 'note','formula', 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD_NEW = ['label', 'metaGroupId', 'groupId',
                              'goodPeakCount', 'maxQuality',
         'medMz', 'medRt', 'isotopeLabel', 'compound', 'formula',
                                 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_UL_PVD_NEW_KEEP_DUPLICATE_NAMES = ['label', 'metaGroupId', 'groupId',
                              'goodPeakCount', 'maxQuality',
         'medMz', 'isotopeLabel', 'formula',
                                 'expectedRtDiff',
         'ppmDiff', 'parent', 'adductName']

EXTRA_COLUMNS_LIST_ISOCORRECT_OUTPUT = [ 'NA Corrected', 'Formula',
                    'Indistinguishale_isotope', 'Pool_total',
                    'Fractional Enrichment', 'Fractional Enrichment with zero',
                    'Truth Value_x', 'Intensity', 'Unlabeled Fragment','Truth Value_y']

EXTRA_COLUMNS_LIST_QUANT_FIT_OUTPUT = ['Point Type', 'Cohort Name',
                    'Metabolite Name', 'Concentration','Normalized Conc']

EXTRA_COLUMNS_LIST_QUANT_FIT_OUTPUT_FOR_METSCAPE = ['Point Type', 'Cohort Name',
                    'Point Name', 'Concentration', 'Normalized Conc']

FORMULA_COLUMN = 'formula'
HMDB = "HMDB"
HMDB_ID = 'HMDB ID'
HMDBID_COLUMN = 'hmdb_id'
ISOTOPELABEL_COLUMN = 'isotopeLabel'
INTENSITY_COLUMN = 'Intensity'
KEGG_COLUMN = 'id'
LABEL_COLUMN = 'Label'
MASS_INFO1 = 'precursorMz'
MASS_INFO2 = 'productMz'
MASS_INFO = 'Mass Info'
MEAN = 'mean'
MESSAGE = 'message'
METABOLITES = 'metabolites'
METABOLITE_NAME = 'Metabolite Name'
METADATA_COL = ['Component Name', 'Method', 'Unlabeled Fragment']
METADATA_FILE = "data_files/metadata_mq_with_method_all.csv"
METHOD = 'Method'
MVN_COL = ['compound', 'sample', 'peakAreaCorrected']
NA_COL = ['Component Name', 'Original Filename', 'Area']
NA_CORRECTED_WITH_ZERO_COLUMN = 'NA Corrected with zero'
NAME_COLUMN = 'Name'
NOTE_COLUMN = 'note'
ORIGINAL_FILENAME = 'Original Filename'
OUTPUT_FILE = 'converted_'
OUTPUT_FILE_NAME = 'converted_output_'
POINT_NAME = 'Point Name'
PDF_FILES = ['report_cover.pdf', 'qc1_cover.pdf', 'plot.pdf', 'qc2_cover.pdf', 'int_plot.pdf' ]
REQUIRED_COL_LIST = ['compound', 'note', 'label', 'metaGroupId', 'groupId', 'groupId',
                     'maxQuality', 'compoundId', 'expectedRtDiff',
                     'ppmDiff', 'medRt', 'parent', 'goodPeakCount',
                     'medMz']
NEW_REQUIRED_COL_LIST = ['compound', 'isotopeLabel', 'label', 'metaGroupId',
                         'groupId', 'groupId',
                     'maxQuality', 'compoundId', 'expectedRtDiff',
                     'ppmDiff', 'medRt', 'parent', 'goodPeakCount',
                     'medMz']
SAMPLE_COLUMN = 'Sample'
SAMPLE_NAME = 'Sample Name'
SMALL_L_LABEL_COLUMN = 'label'
SAMPLE_ID = 'sample_id'
UPPERCASE_FORMULA_COLUMN = 'Formula'
WARNINGS = 'warnings'

#Extentions
XLS_EXT = '.xls'
XLSX_EXT = '.xlsx'
CSV_EXT = '.csv'
TXT_EXT = '.txt'
EXT_DICT = {XLS_EXT: pd.read_excel,
            XLSX_EXT:pd.read_excel,
            CSV_EXT: pd.read_csv,
            TXT_EXT: pd.read_table}
